@@ -103,22 +103,24 @@ class GitFetcher(ReleaseFetcher):
     Fetcher to retrieve data from arbitrary Git repositories
     """
 
-    def __init__(
-        self,
-        repo_url,
-        local_path,
-        major_branch="master",
-        tag_regex=r"^v?((?:\d+\.\d+).*)$",
-    ):
+    def __init__(self, repo_url, local_path, tag_regex=None, tag_substitute=None):
         if not os.path.isdir(local_path):
             Repo.clone_from(repo_url, local_path)
 
         self._local_path = local_path
         self._repo = Repo(local_path)
-        self._repo.git.checkout(major_branch)
+
+        # Checkout an arbitrary branch to ensure the following fetch will work
+        branch = self._repo.branches[0]
+        self._repo.git.checkout(branch)
+        self._current_checkout = branch
+
         self._repo.remotes.origin.pull()
-        self._version_pattern = re.compile(tag_regex)
-        self._current_checkout = major_branch
+        self._version_pattern = (
+            re.compile(tag_regex, flags=re.IGNORECASE)
+            if tag_regex
+            else re.compile(r"^v?((?:\d+\.\d+).*)$", re.IGNORECASE)
+        )
 
         self._tag_mapping = {}
         for tag in self._repo.tags:
@@ -126,7 +128,12 @@ class GitFetcher(ReleaseFetcher):
             if ver is None:
                 print("\tSkipped Tag", tag.name)
                 continue
-            self._tag_mapping[ver.group(1)] = tag
+
+            version_str = ver.group(1)
+            if tag_substitute:
+                version_str = re.sub(tag_substitute[0], tag_substitute[1], version_str)
+
+            self._tag_mapping[version_str] = tag
 
     def _ensure_release(self, version_str):
         tag = self._tag_mapping[version_str]
@@ -153,6 +160,10 @@ class GitFetcher(ReleaseFetcher):
 
             for file_name in files:
                 full_file_path = os.path.join(root, file_name)
+
+                if os.path.islink(full_file_path):
+                    continue
+
                 repo_file_name = os.path.relpath(full_file_path, self._local_path)
                 file_list[repo_file_name] = {"hashes": get_hashes(full_file_path)}
 
